==> design-system-core-0.1.0.tgz: package/stories/forms/SelectInput.stories.js <==
import classNames from 'classnames'

import '../../scss/components/forms/inputs.scss'
import '../../scss/components/forms/input-select.scss'
import '../../scss/components/forms/input-label.scss'
import '../../scss/components/forms/error-message.scss'

/**
 * The standard form select input, shown here with a label, hint, and where applicable an error message
 *
 * **Note:** Make sure to include a label for each input used
 * */
export default {
  title: 'Components/Form/SelectInput',
  tags: ['autodocs'],
  argTypes: {
    disabled: {
      control: 'boolean',
    },
    readonly: {
      control: 'boolean',
    },
    error: {
      control: 'boolean',
    },
  },
  args: {
    disabled: false,
    readonly: false,
    error: false,
  },
}

const SelectInputTemplate = ({ disabled, readonly, error }) => {
  const classnames_wrapper = classNames('rpf-input-field')
  const classnames_label = classNames('rpf-label', {
    'rpf-label--disabled': disabled,
  })
  const classnames_select = classNames('rpf-input rpf-input-select', {
    'rpf-input--error': error,
  })

  return `
    <div class="${classnames_wrapper}">
      <div class="${classnames_label}">
        <label for="sort">Sort by</label>
        <div class="rpf-label__hint" for="sort">Please select which berry to sort by</div>
      </div>
      <select class="${classnames_select}"${disabled || readonly ? ' disabled' : ''} id="sort" name="sort">
        <option value=>Please select</option>
        <option value="bluberry">Blueberry</option>
        <option value="raspberry">Raspberry</option>
        <option value="strawberry">Strawberry</option>
        <option value="gooseberry">Gooseberry</option>
      </select>
      ${
        error
          ? '<div class="rpf-error-message"><span class="rpf-error-message__icon material-symbols-sharp">info</span>Error: Berry selection is required</div>'
          : ''
      }
    </div>
  `
}

export const Default = SelectInputTemplate.bind({})
Default.args = {}

export const Error = SelectInputTemplate.bind({})
Error.args = {
  error: true,
}

export const Readonly = SelectInputTemplate.bind({})
Readonly.args = {
  readonly: true,
}

export const Disabled = SelectInputTemplate.bind({})
Disabled.args = {
  disabled: true,
}

==> design-system-core-0.1.3.tgz: package/stories/forms/SelectInput.stories.js <==
import classNames from 'classnames'

import '../../scss/components/forms/inputs.scss'
import '../../scss/components/forms/input-select.scss'
import '../../scss/components/forms/input-label.scss'
import '../../scss/components/forms/error-message.scss'

/**
 * The standard form select input, shown here with a label, hint, and where applicable an error message
 *
 * **Note:** Make sure to include a label for each input used
 * */
export default {
  title: 'Components/Form/SelectInput',
  tags: ['autodocs'],
  argTypes: {
    disabled: {
      control: 'boolean',
    },
    readonly: {
      control: 'boolean',
    },
    error: {
      control: 'boolean',
    },
    fullWidth: {
      control: 'boolean',
    },
  },
  args: {
    disabled: false,
    readonly: false,
    error: false,
    fullWidth: false,
  },
}

const SelectInputTemplate = ({ disabled, readonly, error, fullWidth }) => {
  const classnames_wrapper = classNames('rpf-input-field')
  const classnames_label = classNames('rpf-label', {
    'rpf-label--disabled': disabled,
  })
  const classnames_select = classNames('rpf-input rpf-input-select', {
    'rpf-input--error': error,
    'rpf-input--full-width': fullWidth,
  })

  return `
    <div class="${classnames_wrapper}">
      <label for="sort" class="${classnames_label}">
        Sort by
        <small class="rpf-label__hint">Please select which berry to sort by</small>
      </label>
      <select class="${classnames_select}"${disabled || readonly ? ' disabled' : ''} id="sort" name="sort">
        <option value=>Please select</option>
        <option value="bluberry">Blueberry</option>
        <option value="raspberry">Raspberry</option>
        <option value="strawberry">Strawberry</option>
        <option value="gooseberry">Gooseberry</option>
      </select>
      ${
        error
          ? '<div class="rpf-error-message"><span class="rpf-error-message__icon material-symbols-sharp">info</span>Error: Berry selection is required</div>'
          : ''
      }
    </div>
  `
}

export const Default = SelectInputTemplate.bind({})
Default.args = {}

export const Error = SelectInputTemplate.bind({})
Error.args = {
  error: true,
}

export const Readonly = SelectInputTemplate.bind({})
Readonly.args = {
  readonly: true,
}

export const Disabled = SelectInputTemplate.bind({})
Disabled.args = {
  disabled: true,
}

export const FullWidth = SelectInputTemplate.bind({})
FullWidth.args = {
  fullWidth: true,
}
